Internal API
============

This documents the internal API that might be useful for more advanced
setups or custom handlers.

.. currentmodule:: logbook.base

.. autofunction:: dispatch_record

.. autoclass:: StackedObject
   :members:

.. autoclass:: RecordDispatcher
   :members:

.. autoclass:: LoggerMixin
   :members:
   :inherited-members:

.. currentmodule:: logbook.handlers

.. autoclass:: StringFormatterHandlerMixin
   :members:
